@@ -17,10 +17,7 @@ MediaTransport::MediaTransport(const QString &path, const QVariantMap &propertie
 {
 }
 
-MediaTransport::~MediaTransport()
-{
-    delete d;
-}
+MediaTransport::~MediaTransport() = default;
 
 AudioConfiguration MediaTransport::audioConfiguration() const
 {
@@ -39,17 +36,19 @@ quint16 MediaTransport::volume() const
 
 TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t> *MediaTransport::acquire()
 {
-    return new TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t>(d->m_dbusInterface->asyncCall(QStringLiteral("Acquire")), this);
+    return new TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t>(d->m_dbusInterface.Acquire(), this);
 }
 
 TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t> *MediaTransport::tryAcquire()
 {
-    return new TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t>(d->m_dbusInterface->asyncCall(QStringLiteral("TryAcquire")), this);
+    return new TPendingCall<QDBusUnixFileDescriptor, uint16_t, uint16_t>(d->m_dbusInterface.TryAcquire(), this);
 }
 
 TPendingCall<void> *MediaTransport::release()
 {
-    return new TPendingCall<void>(d->m_dbusInterface->asyncCall(QStringLiteral("Release")), this);
+    return new TPendingCall<void>(d->m_dbusInterface.Release(), this);
 }
 
 } // namespace BluezQt
+
+#include "moc_mediatransport.cpp"
