@@ -11,14 +11,14 @@
 #include <QDBusUnixFileDescriptor>
 #include <QDebug>
 
+#include "adapter.h"
 #include "device.h"
 #include "initmanagerjob.h"
 #include "media.h"
 #include "mediaendpoint.h"
 #include "mediatransport.h"
-#include "tpendingcall.h"
 #include "services.h"
-#include "adapter.h"
+#include "tpendingcall.h"
 
 using namespace BluezQt;
 
@@ -35,10 +35,7 @@ NoInputNoOutputAgent::NoInputNoOutputAgent(const QStringList &uuids, QObject *pa
     d->allowedUuids = uuids;
 }
 
-NoInputNoOutputAgent::~NoInputNoOutputAgent()
-{
-    delete d;
-}
+NoInputNoOutputAgent::~NoInputNoOutputAgent() = default;
 
 QDBusObjectPath NoInputNoOutputAgent::objectPath() const
 {
@@ -89,7 +86,7 @@ void MediaEndpointConnector::onTransportChanged(MediaTransportPtr transport)
         return;
     }
 
-    connect(transport.data(), &MediaTransport::stateChanged, [transport](MediaTransport::State state){
+    connect(transport.data(), &MediaTransport::stateChanged, [transport](MediaTransport::State state) {
         qDebug() << "Transport state:" << state;
 
         if (state == MediaTransport::State::Pending) {
@@ -99,7 +96,7 @@ void MediaEndpointConnector::onTransportChanged(MediaTransportPtr transport)
             });
         }
     });
-    connect(transport.data(), &MediaTransport::volumeChanged, [](quint16 volume){
+    connect(transport.data(), &MediaTransport::volumeChanged, [](quint16 volume) {
         qDebug() << "Transport volume:" << volume;
     });
 }
@@ -156,3 +153,5 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
+
+#include "moc_mediaendpointconnector.cpp"
